@@ -103,7 +103,7 @@ class TextPreprocessor:
                 (;-?\)+ | [-=][)(]+ | -_- | ^-^)          # 8
                 (\.|\s|$)                                 # 9
             )|(?:
-                ([\u2660-\u26ff\U00010000-\U0010ffff])    # 10
+                ([\u2660-\u27ff\U00010000-\U0010ffff])    # 10
             )|(?:
                 (^|[^)(:;=-])                             # 11
                 (\)\)+ | \(\(+)                           # 12
@@ -255,7 +255,7 @@ class TextPreprocessor:
         )
         self.TAG_HASHTAG = self.register_tag('EntityHashtag')
         self.RE_NAMETAG = re_compile(
-            r'(?mu)(^|[\s(])(@' + self.CHAR_ALPHA + self.CHAR_ALNUM_
+            r'(?mu)(^|[\s(])(@[A-Za-z0-9._]'# + self.CHAR_ALPHA + self.CHAR_ALNUM_
           + r'{,138})\b(?!\S*' + re_char_delim + ')'
         )
         self.TAG_NAMETAG = self.register_tag('EntityNametag', mask='ссылка')
